<?php

namespace Litecms\Visitor\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Visitor\Interfaces\VisitorRepositoryInterface;

class VisitorPublicController extends BaseController
{
    // use VisitorWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Visitor\Interfaces\VisitorRepositoryInterface $visitor
     *
     * @return type
     */
    public function __construct(VisitorRepositoryInterface $visitor)
    {
        $this->repository = $visitor;
        parent::__construct();
    }

    /**
     * Show visitor's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $visitors = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$visitor::$visitor.names'))
            ->view('$visitor::public.visitor.index')
            ->data(compact('$visitors'))
            ->output();
    }

    /**
     * Show visitor's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $visitors = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$visitor::$visitor.names'))
            ->view('$visitor::public.visitor.index')
            ->data(compact('$visitors'))
            ->output();
    }

    /**
     * Show visitor.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $visitor = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$visitor->name . trans('$visitor::$visitor.name'))
            ->view('$visitor::public.visitor.show')
            ->data(compact('$visitor'))
            ->output();
    }

}
